PSAS Packet Serializer
======================

.. image:: https://badge.fury.io/py/psas_packet.png
    :target: http://badge.fury.io/py/psas_packet

.. image:: https://travis-ci.org/psas/psas_packet.png
    :target: https://travis-ci.org/psas/psas_packet

.. image:: https://coveralls.io/repos/psas/psas_packet/badge.png?branch=master
    :target: https://coveralls.io/r/psas/psas_packet?branch=master


Reusable `Portland State Aerospace Society <http://psas.pdx.edu/>`_ telemetry
packet encoder, decoder, documentation, and other tools.


Documentation
-------------

http://psas-packet-serializer.readthedocs.org

Install
~~~~~~~

::

    pip install psas_packet


Develop
~~~~~~~

Install locally in a virtual env::

    python setup.py install

Do work and test::

    python setup.py test


License
-------

::

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
